#[non_exhaustive]pub enum RxErrorKind {
FifoOverflowed,
GlitchOccurred,
FrameFormatViolated,
ParityMismatch,
}Available on crate feature
unstable only.Expand description
UART RX error conditions that can be reported by read operations.
This enum can be used with RxConfig::with_reported_errors to choose
which hardware RX error conditions should make read operations return an
RxError.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FifoOverflowed
An RX FIFO overflow happened.
GlitchOccurred
A glitch was detected on the RX line.
FrameFormatViolated
A framing error was detected on the RX line.
ParityMismatch
A parity error was detected on the RX line.